@@ -2,6 +2,7 @@ package Router::Simple::SubMapper;
 use strict;
 use warnings;
 use Scalar::Util qw/weaken/;
+use Router::Simple ();
 
 sub new {
     my ($class, %args) = @_;
@@ -25,6 +26,14 @@ sub connect {
     $self; # chained method
 }
 
+# Allow nested submapper calls
+sub submapper {
+    my $self = shift;
+
+    Router::Simple::submapper($self, @_);
+}
+
+
 1;
 __END__
 
@@ -62,6 +71,12 @@ This method creates new route to parent $router with @args and arguments of ->su
 
 This method returns $submapper itself for method-chain.
 
+=item $submapper->submapper(%args)
+
+submapper() can be called recursively to build nested routes.
+
+This method returns $submapper itself for method-chain.
+
 =back
 
 =head1 SEE ALSO
